@@ -273,6 +273,8 @@ private:
   grn_obj *cursor_geo;
   grn_table_cursor *cursor;
   grn_table_cursor *index_table_cursor;
+  grn_obj *empty_value_records;
+  grn_table_cursor *empty_value_records_cursor;
   grn_obj *sorted_result;
   grn_obj *matched_record_keys;
   String  *blob_buffers;
@@ -537,6 +539,7 @@ private:
   void push_warning_unsupported_spatial_index_search(enum ha_rkey_function flag);
   void clear_cursor();
   void clear_cursor_geo();
+  void clear_empty_value_records();
   void clear_search_result();
   void clear_search_result_geo();
   void clear_indexes();
@@ -765,16 +768,16 @@ private:
                                               KEY *key_info,
                                               grn_obj *index_column);
   int storage_write_row_multiple_column_indexes(uchar *buf, grn_id record_id);
-  int storage_write_row_unique_index(uchar *buf, grn_id record_id,
+  int storage_write_row_unique_index(uchar *buf,
                                      KEY *key_info, grn_obj *index_table,
                                      grn_id *key_id);
-  int storage_write_row_unique_indexes(uchar *buf, grn_id record_id);
+  int storage_write_row_unique_indexes(uchar *buf);
   int wrapper_get_record_id(uchar *data, grn_id *record_id, const char *context);
   int wrapper_update_row(const uchar *old_data, uchar *new_data);
   int wrapper_update_row_index(const uchar *old_data, uchar *new_data);
   int storage_update_row(const uchar *old_data, uchar *new_data);
   int storage_update_row_index(const uchar *old_data, uchar *new_data);
-  int storage_update_row_unique_indexes(uchar *new_data, grn_id record_id);
+  int storage_update_row_unique_indexes(uchar *new_data);
   int wrapper_delete_row(const uchar *buf);
   int wrapper_delete_row_index(const uchar *buf);
   int storage_delete_row(const uchar *buf);
