@@ -20,6 +20,7 @@
 
 export BASE_DIR="$(cd $(dirname $0); pwd)"
 top_dir="$BASE_DIR/.."
+mroonga_test_dir="${top_dir}/mysql-test/mroonga"
 
 n_processors=1
 case `uname` in
@@ -97,23 +98,12 @@ same_link_p()
     fi
 }
 
-mroonga_mysql_test_include_dir="${build_test_include_dir}/mroonga"
-if ! same_link_p "${mroonga_mysql_test_include_dir}"; then
-    rm -f "${mroonga_mysql_test_include_dir}"
-    ln -s "${BASE_DIR}/sql/include/mroonga" "${mroonga_mysql_test_include_dir}"
+mroonga_mysql_test_suite_dir="${build_test_suites_dir}/mroonga"
+if ! same_link_p "${mroonga_test_dir}" "${mroonga_mysql_test_suite_dir}"; then
+    rm -rf "${mroonga_mysql_test_suite_dir}"
+    ln -s "${mroonga_test_dir}" "${mroonga_mysql_test_suite_dir}"
 fi
 
-for test_suite_name in mroonga; do
-    local_mroonga_mysql_test_suite_dir="${BASE_DIR}/sql/suite/${test_suite_name}"
-    mroonga_mysql_test_suite_dir="${build_test_suites_dir}/${test_suite_name}"
-    if ! same_link_p "${local_mroonga_mysql_test_suite_dir}" \
-			"${mroonga_mysql_test_suite_dir}"; then
-	rm -f "${mroonga_mysql_test_suite_dir}"
-	ln -s "${local_mroonga_mysql_test_suite_dir}" \
-	    "${mroonga_mysql_test_suite_dir}"
-    fi
-done
-
 innodb_test_suite_dir="${build_test_suites_dir}/innodb"
 mroonga_wrapper_innodb_test_suite_name="mroonga_wrapper_innodb"
 mroonga_wrapper_innodb_test_suite_dir="${build_test_suites_dir}/${mroonga_wrapper_innodb_test_suite_name}"
@@ -138,14 +128,19 @@ if [ ! -d "${mroonga_wrapper_innodb_test_suite_dir}" ]; then
 	${mroonga_wrapper_innodb_test_suite_dir}/t/*.test \
 	${mroonga_wrapper_innodb_test_suite_dir}/include/*.inc
     sed -i'' \
-	-e '1 i --source include/mroonga/have_mroonga.inc' \
+	-e '1 i --source ../mroonga/include/mroonga/have_mroonga.inc' \
 	${mroonga_wrapper_innodb_test_suite_dir}/t/*.test
 fi
 
 all_test_suite_names=""
-suite_dir="${BASE_DIR}/sql/suite"
+suite_dir="${mroonga_test_dir}/.."
 cd "${suite_dir}"
-for test_suite_name in $(find mroonga -type d '!' -name '[tr]'); do
+suite_dir="$(pwd)"
+for test_suite_name in \
+      $(find mroonga -type d -name 'include' '!' -prune -o \
+                     -type d '!' -name 'mroonga' \
+                             '!' -name 'include' \
+                             '!' -name '[tr]'); do
     if [ -n "${all_test_suite_names}" ]; then
 	all_test_suite_names="${all_test_suite_names},"
     fi
@@ -192,6 +187,14 @@ while [ $# -gt 0 ]; do
 		    ;;
 	    esac
 	    shift
+
+	    if [ -n "${test_name}" ]; then
+		if [ -n "${test_names}" ]; then
+		    test_names="${test_names}|"
+		fi
+		test_names="${test_names}.*${test_name}"
+	    fi
+
 	    test_suite_name=$(echo "$test_suite_name" | sed -e "s,^${suite_dir}/,,")
 	    if echo "${test_suite_names}" | grep --quiet "${test_suite_name}"; then
 		continue
@@ -200,12 +203,6 @@ while [ $# -gt 0 ]; do
 		test_suite_names="${test_suite_names},"
 	    fi
 	    test_suite_names="${test_suite_names}${test_suite_name}"
-	    if [ -n "${test_name}" ]; then
-		if [ -n "${test_names}" ]; then
-		    test_names="${test_names},"
-		fi
-		test_names="${test_names}${test_name}"
-	    fi
 	    ;;
     esac
 done
